The most interesting files are:

template.py
    The hypergen template engine
liveview.py
    Liveview capabilities that updates the page dynamically
context.py
    The immutable global context dictionary that is a vital part of hypergen
imports.py
    Gotta catch them all? Import from here.
hypergen.py
    Internal helpers


These belong to an older version of hypergen and will go away:

core.py
    The hypergen template engine and lieview features all mixed up
contrib.py
    QOL view decorators
